%define shortname centos-ds
%define pkgname   dirsrv

Summary:          CentOS Directory Server (base)
Name:             centos-ds-base
Version:          8.1.0
Release:          0.14%{?dist}.2
License:          GPLv2 with exceptions
URL:              http://www.centos.org/
Group:            System Environment/Daemons
BuildRoot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:    nspr-devel >= 4.6.4.1
BuildRequires:    nss-devel >= 3.11.4
BuildRequires:    svrcore-devel >= 4.0.3
BuildRequires:    mozldap-devel >= 6.0.4
BuildRequires:    db4-devel >= 4.2.52
BuildRequires:    cyrus-sasl-devel >= 2.1.19
BuildRequires:    icu >= 3.4
BuildRequires:    libicu-devel >= 3.4
# The following are needed to build the snmp ldap-agent
BuildRequires:    net-snmp-devel >= 5.1.2
%ifnarch sparc sparc64 ppc ppc64
BuildRequires:    lm_sensors-devel
%endif
BuildRequires:    zlib-devel
BuildRequires:    openssl-devel
BuildRequires:    tcp_wrappers
BuildRequires:    libselinux-devel
# the following is for the pam passthru auth plug-in
# which is disabled for centos directory server for now
#BuildRequires:    pam-devel

# the following are needed for some of our scripts
Requires:         mozldap-tools
Requires:         perl-Mozilla-LDAP

# this is needed to setup SSL if you are not using the
# administration server package
Requires:         nss-tools

# these are not found by the auto-dependency method
# they are required to support the mandatory LDAP SASL mechs
Requires:	      cyrus-sasl-gssapi
Requires:	      cyrus-sasl-md5

# this is needed for verify-db.pl
Requires:             db4-utils

# for the init script
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
Requires(preun): /sbin/service

Source0:          %{name}-%{version}.tar.bz2
Source1:          %{name}-devel.README

%description
CentOS Directory Server is an LDAPv3 compliant server.  The base package includes
the LDAP server and command line utilities for server administration.

%package          devel
Summary:          Development libraries for CentOS Directory Server
Group:            Development/Libraries
Requires:         %{name} = %{version}-%{release}
Requires:         mozldap-devel

%description      devel
Development Libraries and headers for the CentOS Directory Server base package.


%prep
%setup -q -n %{name}-%{version}
cp %{SOURCE1} README.devel

%build
# %configure --disable-ldapi --disable-bitwise --disable-pam-passthru --disable-dna
%configure --disable-bitwise --disable-pam-passthru --enable-ldapi --enable-autobind

# Generate symbolic info for debuggers
export XCFLAGS=$RPM_OPT_FLAGS

%ifarch x86_64 ppc64 ia64 s390x sparc64
export USE_64=1
%endif

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT 

make DESTDIR="$RPM_BUILD_ROOT" install

mkdir -p $RPM_BUILD_ROOT/var/log/%{pkgname}
mkdir -p $RPM_BUILD_ROOT/var/lib/%{pkgname}
mkdir -p $RPM_BUILD_ROOT/var/lock/%{pkgname}
mkdir -p $RPM_BUILD_ROOT%{_includedir}/%{pkgname}

#remove libtool and static libs
rm -f $RPM_BUILD_ROOT%{_libdir}/%{pkgname}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{pkgname}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/%{pkgname}/plugins/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{pkgname}/plugins/*.la

install -p -m 644 ldap/servers/slapd/slapi-plugin.h $RPM_BUILD_ROOT%{_includedir}/%{pkgname}/
install -p -m 644 ldap/servers/plugins/replication/winsync-plugin.h $RPM_BUILD_ROOT%{_includedir}/%{pkgname}/

# make sure perl scripts have a proper shebang 
sed -i -e 's|#{{PERL-EXEC}}|#!/usr/bin/perl|' $RPM_BUILD_ROOT%{_datadir}/%{pkgname}/script-templates/template-*.pl

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/chkconfig --add %{pkgname}
/sbin/ldconfig


%preun
if [ $1 = 0 ]; then
        /sbin/service %{pkgname} stop >/dev/null 2>&1 || :
        /sbin/chkconfig --del %{pkgname}
fi

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc LICENSE EXCEPTION
%dir %{_sysconfdir}/%{pkgname}
%dir %{_sysconfdir}/%{pkgname}/schema
%config(noreplace)%{_sysconfdir}/%{pkgname}/schema/*.ldif
%dir %{_sysconfdir}/%{pkgname}/config
%config(noreplace)%{_sysconfdir}/%{pkgname}/config/slapd-collations.conf
%config(noreplace)%{_sysconfdir}/%{pkgname}/config/certmap.conf
%config(noreplace)%{_sysconfdir}/sysconfig/%{pkgname}
%{_datadir}/%{pkgname}
%{_initrddir}/%{pkgname}
%{_bindir}/*
%{_sbindir}/*
%dir %{_libdir}/%{pkgname}
%{_libdir}/%{pkgname}/*.so.*
%{_libdir}/%{pkgname}/perl
%dir %{_libdir}/%{pkgname}/plugins
%{_libdir}/%{pkgname}/plugins/*.so
%dir %{_localstatedir}/lib/%{pkgname}
%dir %{_localstatedir}/log/%{pkgname}
%dir %{_localstatedir}/lock/%{pkgname}
%{_mandir}/man1/*
%{_mandir}/man8/*

%files devel
%defattr(-,root,root,-)
%doc LICENSE EXCEPTION README.devel
%{_includedir}/%{pkgname}
%{_libdir}/%{pkgname}/*.so

%changelog
* Thu May 14 2009 Tim Verhoeven <tim@centos.org> - 8.1.0-0.14.el5.centos.2
- Rebuild + Rebranding.

* Tue Apr 21 2009 Nathan Kinder <nkinder@redhat.com> - 8.1.0-14.el5dsrv
- Resolves: Bug 496836
- Description: corrected semaphore name used by SNMP subagent
- CVS tag Directory_Server_8_1_Candidate_20090421

* Thu Apr 16 2009 Noriko Hosoi <nhosoi@redhat.com> - 8.1.0-0.13.el5dsrv
- Resolves: Bug 475338
- Description: LOG: the intenal type of maxlogsize, maxdiskspace and minfreespace should be 64-bit integer (comment #23)
- CVS tag Directory_Server_8_1_Candidate_20090416

* Thu Apr 16 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-0.12.el5dsrv
- used incorrect dist tag

* Thu Apr 16 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-0.11.el5dsrv
- Resolves: Bug 475338
- Description: LOG: the intenal type of maxlogsize, maxdiskspace and minfreespace should be 64-bit integer
- CVS tag Directory_Server_8_1_Candidate_20090416

* Thu Apr 02 2009 Nathan Kinder <nkinder@redhat.com> - 8.1.0-0.10.el5dsrv
- Fix return status for init script.

* Wed Apr 1 2009 Kevin Wright <kwright@redhat.com> - 8.1.0-0.9.el5dsrv
- Respin using DSRV-8-RHEL5 branch instead of DSRV-8_1-RHEL5.

* Tue Mar 31 2009 Kevin Wright <kwright@redhat.com> - 8.1.0-0.8.el5dsrv
- Initial brew build for 8.1.0

* Fri Jan 30 2009 Nathan Kinder <nkinder@redhat.com> - 8.1.0-0.7.el5dsrv
- Made devel package depend on mozldap-devel

* Mon Oct 30 2008 Noriko Hosoi <nhosoi@redhat.com> - 8.1.0-0.6.el5dsrv
- added db4-utils to Requires for verify-db.pl

* Tue Oct 14 2008 Tim Verhoeven <tim@centos.org> - 8.0.4-7.el5.centos.0
- Rebuild of 8.0.4-7

* Tue Aug 12 2008 Rich Megginson <rmeggins@redhat.com> - 8.0.4-7.el4dsrv
- internal files were put in source tarball - remove and rebuild

* Tue Aug 12 2008 Rich Megginson <rmeggins@redhat.com> - 8.0.4-6.el4dsrv
- Resolves: bug 458506 - CVE-2008-3283 SASL bind can leak credentials in some cases
- Resolves: bug 458507 - Memory leak setting new password storage scheme
- Resolves: bug 458510 - Memory leak setting password with passwd extop
- Resolves: bug 458666 - Memory leaks in check_trivial_words, check_pw_storagescheme_value
- Resolves: bug 458668 - Memory leaks in ids_sasl_user_search
- Resolves: bug 458675 - Memory leaks in valueset code
- Resolves: bug 458677 - Memory leaks in index code doing indexed & range & matching rule searches

* Thu Aug  7 2008 Rich Megginson <rmeggins@redhat.com> - 8.0.4-5.el5dsrv
- Resolves: bug 458171 - approx search accidentally fails with timelimit although it hasn't hit timelimit.

* Mon Jul 21 2008 Nathan Kinder <nkinder@redhat.com> - 8.0.4-4.el5dsrv
- Use timelimit in regex code.

* Mon Jul 14 2008 Nathan Kinder <nkinder@redhat.com> - 8.0.4-3.el5dsrv
- Several important stability fixes

* Wed May 14 2008 Tim Verhoeven <tim@centos.org> - 8.0.3-16.el5.centos.1
- Rebuild of 8.0.3-16

* Tue Apr 29 2008 Noriko Hosoi <nhosoi@redhat.com> - 8.0.3-16.el5dsrv
- Imported new sources for bug 182621

* Fri Apr 18 2008 Noriko Hosoi <nhosoi@redhat.com> - 8.0.0-15.el5dsrv
- Fix memory leaks in extensible filter code

* Wed Apr 02 2008 Tim Verhoeven <tim@centos.org> - 8.0.0-14.el5.centos.4
- Rebuild of 8.0.0-14

* Wed Apr 02 2008 Tim Verhoeven <tim@centos.org> - 8.0.0-11.el5.centos.4
- Rebranding

* Mon Mar 03 2008 Nathan Kinder <nkinder@redhat.com> - 8.0.0-14.el5dsrv
- Rebuild.

* Mon Mar 03 2008 Nathan Kinder <nkinder@redhat.com> - 8.0.0-13.el5dsrv
- Fix fractional replication between masters.

* Tue Nov 06 2007 Margaret Lum <mlum@redhat.com> - 8.0.0-11.el5dsrv
- Build officially in Brew.

* Wed Oct 17 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-6.el5dsrv
- remove /var/tmp/dirsrv from package

* Fri Oct  5 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-5.el5dsrv
- The file /etc/sysconfig/dirsrv has been added to the package

* Thu Aug 16 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-4.el5dsrv
- several migration fixes
- fix usage of open() with O_CREAT and db4->open() calls
- update License to GPLv2 with exceptions as per Fedora

* Fri Aug 10 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-3
- Change pathnames to use the pkgname macro which is dirsrv

* Fri Aug 10 2007 Noriko Hosoi <nhosoi@redhat.com> - 8.0.0-2
- upgraded mozldap version to 6.0.4

* Tue Jul 24 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1
- removed fedora-isms, cvsdate

* Tue Jul 24 2007 Margaret Lum <mlum@redhat.com> - 8.0.0-0.3.el5dsrv
- Adding back in cvsdate

* Mon Jul 23 2007 Margaret Lum <mlum@redhat.com> - 8.0.0-0.2.el5dsrv
- Use %{?dist} defined in buildsys-macros

* Mon Jul 23 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-0.1.20070723
- initial version based on fedora-ds-base.spec
